@@ -13,26 +13,23 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from ripe.atlas.cousteau import Measurement
+from ripe.atlas.cousteau import Measurement, AtlasStream
 from ripe.atlas.cousteau.exceptions import APIResponseError
 
 from ..exceptions import RipeAtlasToolsException
 from ..renderers import Renderer
-from ..streaming import Stream
-from .base import Command as BaseCommand
+from ..streaming import StreamWrapper
 from ..helpers.validators import ArgumentType
+from ..settings import conf
+from .base import Command as BaseCommand
 
 
 class Command(BaseCommand):
 
     NAME = "stream"
 
-    DESCRIPTION = (
-        "Output the results of a public measurement as they become available"
-    )
-    EXTRA_DESCRIPTION = (
-        "Streaming of non-public measurements is not supported."
-    )
+    DESCRIPTION = "Output the results of a public measurement as they become available"
+    EXTRA_DESCRIPTION = "Streaming of non-public measurements is not supported."
     URLS = {
         "detail": "/api/v2/measurements/{0}.json",
     }
@@ -54,11 +51,18 @@ class Command(BaseCommand):
             help="The renderer you want to use. If this isn't defined, an "
             "appropriate renderer will be selected.",
         )
+        self.parser.add_argument(
+            "--timeout",
+            type=float,
+            help="Stop streaming after this number of seconds",
+        )
+        self.parser.add_argument(
+            "--send-backlog", action="store_true", help="Send backlog of recent results"
+        )
 
         Renderer.add_arguments_for_available_renderers(self.parser)
 
-    def run(self):
-
+    def run(self) -> None:
         try:
             measurement = Measurement(
                 id=self.arguments.measurement_id,
@@ -68,11 +72,21 @@ class Command(BaseCommand):
             raise RipeAtlasToolsException(e.args[0])
 
         self.ok("Connecting to stream...")
-        stream = Stream(
-            self.arguments.measurement_id, capture_limit=self.arguments.limit
+        stream = AtlasStream(base_url=conf["stream-base-url"])
+        stream.connect()
+        stream.subscribe(
+            "result",
+            msm=self.arguments.measurement_id,
+            sendBacklog=self.arguments.send_backlog,
         )
         renderer = Renderer.get_renderer(
             name=self.arguments.renderer, kind=measurement.type.lower()
         )(arguments=self.arguments)
-        renderer.render(stream)
+        renderer.render(
+            StreamWrapper(
+                stream,
+                capture_limit=self.arguments.limit,
+                timeout=self.arguments.timeout,
+            )
+        )
         self.ok("Disconnected from stream")
